@@ -1,6 +1,6 @@
 /*
  *========================================================================
- * $Id: dieharder.h 267 2007-01-27 15:53:36Z rgb $
+ * $Id: dieharder.h 416 2008-08-17 16:31:18Z rgb $
  *
  * See copyright in copyright.h and the accompanying file COPYING
  *========================================================================
@@ -8,6 +8,9 @@
 
 #include "copyright.h"
 
+/* To enable large file support */
+#define _FILE_OFFSET_BITS 64
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -59,6 +62,14 @@
  */
 #define nullfree(a) {free(a);a = 0;}
 
+/*
+ * This is how one gets a macro into quotes; an important one to keep
+ * in all program templates.
+ */
+#define _QUOTEME(x) #x
+#define QUOTEME(x) _QUOTEME(x)
+
+
  /*
   *========================================================================
   * Subroutine Prototypes
@@ -81,6 +92,47 @@
  double kstest_kuiper(double *pvalue,int count);
  double q_ks(double x);
  double q_ks_kuiper(double x);
+ void Exit(int);
+
+ double output_rnds(void);
+ void add_my_types(void);
+ void help_user_template(void);
+ void list_rngs(void);
+ void parsecl(int argc, char **argv);
+ void run_diehard_2dsphere(void);
+ void run_diehard_3dsphere(void);
+ void run_diehard_birthdays(void);
+ void run_diehard_bitstream(void);
+ void run_diehard_count_1s_byte(void);
+ void run_diehard_count_1s_stream(void);
+ void run_diehard_craps(void);
+ void run_diehard_dna(void);
+ void run_diehard_operm5(void);
+ void run_diehard_opso(void);
+ void run_diehard_oqso(void);
+ void run_diehard_parking_lot(void);
+ void run_diehard_rank_32x32(void);
+ void run_diehard_rank_6x8(void);
+ void run_diehard_runs(void);
+ void run_diehard_squeeze(void);
+ void run_diehard_sums(void);
+ void run_marsaglia_tsang_gcd(void);
+ void run_rgb_bitdist(void);
+ void run_rgb_persist(void);
+ void run_rgb_timing(void);
+ void run_sts_monobit(void);
+ void run_sts_runs(void);
+ void run_user_template(void);
+ void startup(void);
+ void user_template(Test **test,int irun);
+ void work(void);
+ void Xtest_eval(Xtest *xtest);
+
+#ifdef RDIEHARDER
+ int histogram(double *input,int inum,double min,double max,int nbins,char *label);
+ Test *rdh_testptr;		/* kludge: need a global to report back to main + R */
+ Dtest *rdh_dtestptr;	/* kludge: need a global to report back to main + R */
+#endif
 
 
  /*
@@ -109,7 +161,7 @@
  int rgb;               /* rgb test number */
  int sts;               /* sts test number */
  uint Seed;             /* user selected seed.  Surpresses reseeding per sample.*/
- uint tsamples;         /* Generally should be "a lot". */
+ off_t tsamples;        /* Generally should be "a lot".  off_t is u_int64_t. */
  int user;              /* user defined test number */
  int verbose;           /* Default is not to be verbose. */
  double x_user;         /* General purpose command line inputs for use */
@@ -154,14 +206,12 @@
  char filename[K];      /* Input file name */
  int fromfile;		/* set true if file is used for rands */
  int filenumbits;	/* number of bits per integer */
- uint filecount;	/* number of rands in file */
- char filetype;         /* file type */
-
  /*
-  * rng global vectors and variables for setup and tests.
+  * If we have large files, we can have a lot of rands.  off_t is
+  * automagically set to u_int64_t if FILE_OFFSET_BITS is set to 64.
   */
- const gsl_rng_type **types;    /* where all the rng types go */
- gsl_rng *rng;                  /* global gsl random number generator */
+ off_t filecount;	/* number of rands in file */
+ char filetype;         /* file type */
 
  void show_test_header(Dtest *dtest,Test **test);
  void show_test_header_debug(Dtest *dtest,Test **test);
