@@ -1,6 +1,6 @@
 /*
  *========================================================================
- * $Id: work.c 255 2007-01-27 15:09:15Z rgb $
+ * $Id: work.c 406 2008-03-27 16:33:04Z rgb $
  *
  * See copyright in copyright.h and the accompanying file COPYING
  *========================================================================
@@ -29,6 +29,9 @@ void work()
    run_rgb_timing();
    run_rgb_persist();
    run_rgb_bitdist();
+   /*  run_rgb_operm(); */
+   run_rgb_permutations();
+   run_rgb_minimum_distance();
    run_diehard_birthdays();
    run_diehard_operm5();
    run_diehard_rank_32x32();
@@ -50,86 +53,87 @@ void work()
    /* marsaglia_tsang_gorilla(); */
    run_sts_monobit();
    run_sts_runs();
+   run_sts_serial();
    run_user_template();
-   exit(0);
+   Exit(0);
  }
 
  switch(diehard){
    case DIEHARD_BDAY:
      run_diehard_birthdays();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_OPERM5:
      run_diehard_operm5();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_RANK_32x32:
      run_diehard_rank_32x32();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_RANK_6x8:
      run_diehard_rank_6x8();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_BITSTREAM:
      run_diehard_bitstream();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_OPSO:
      run_diehard_opso();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_OQSO:
      run_diehard_oqso();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_DNA:
      run_diehard_dna();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_COUNT_1S_STREAM:
      run_diehard_count_1s_stream();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_COUNT_1S_BYTE:
      run_diehard_count_1s_byte();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_PARKING_LOT:
      run_diehard_parking_lot();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_2DSPHERE:
      run_diehard_2dsphere();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_3DSPHERE:
      run_diehard_3dsphere();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_SQUEEZE:
      run_diehard_squeeze();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_SUMS:
      run_diehard_sums();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_RUNS:
      run_diehard_runs();
-     exit(0);
+     Exit(0);
      break;
    case DIEHARD_CRAPS:
      run_diehard_craps();
-     exit(0);
+     Exit(0);
      break;
    case MARSAGLIA_TSANG_GCD:
      run_marsaglia_tsang_gcd();
-     exit(0);
+     Exit(0);
      break;
    case MARSAGLIA_TSANG_GORILLA:
      /* marsaglia_tsang_gorilla(); */
-     exit(0);
+     Exit(0);
      break;
    default:
      break;
@@ -138,20 +142,32 @@ void work()
  switch(rgb){
    case RGB_TIMING:
      run_rgb_timing();
-     exit(0);
+     Exit(0);
      break;
    case RGB_PERSIST:
      run_rgb_persist();
-     exit(0);
+     Exit(0);
      break;
    case RGB_BITDIST:
      run_rgb_bitdist();
-     exit(0);
+     Exit(0);
      break;
-/*   case RGB_LMN:
+   case RGB_LMN:
      rgb_lmn();
-     exit(0);
-     break; */
+     Exit(0);
+     break;
+   case RGB_OPERM:
+     run_rgb_operm();
+     Exit(0);
+     break;
+   case RGB_PERMUTATIONS:
+     run_rgb_permutations();
+     Exit(0);
+     break;
+   case RGB_MINIMUM_DISTANCE:
+     run_rgb_minimum_distance();
+     Exit(0);
+     break;
    default:
      break;
  }
@@ -159,11 +175,15 @@ void work()
  switch(sts){
    case STS_MONOBIT:
      run_sts_monobit();
-     exit(0);
+     Exit(0);
      break;
    case STS_RUNS:
      run_sts_runs();
-     exit(0);
+     Exit(0);
+     break;
+   case STS_SERIAL:
+     run_sts_serial();
+     Exit(0);
      break;
    default:
      break;
@@ -172,12 +192,14 @@ void work()
  switch(user){
    case USER_TEMPLATE:
      run_user_template();
-     exit(0);
+     Exit(0);
      break;
    default:
      break;
  }
 
+#if !defined(RDIEHARDER)
  list_rngs();
+#endif   /* !defined(RDIEHARDER */
 
 }
